#
# spec file for package latex2html
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define share_dir %{_datadir}/latex2html
%define _texmfmaindir   %{_datadir}/texmf
Name:           latex2html
Version:        2025
Release:        2.1
Summary:        LaTeX to HTML Converter
License:        GPL-2.0-or-later
Group:          Productivity/Publishing/TeX/Utilities
URL:            https://github.com/latex2html/latex2html/
Source0:        %{url}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE latex2html-share-dir.diff -- Fix latex2html share dir location, use /usr/share not /usr/share/lib
Patch0:         latex2html-share-dir.diff
BuildRequires:  fdupes
BuildRequires:  ghostscript-fonts-std
BuildRequires:  ghostscript-x11
BuildRequires:  netpbm
BuildRequires:  texlive-dvips
BuildRequires:  texlive-kpathsea
BuildRequires:  texlive-latex
Requires:       ghostscript_any
Requires:       latex2html-pngicons
Requires:       netpbm
Requires:       perl
Requires:       texlive-dvips
Requires:       texlive-latex
Requires:       texlive-preview
BuildArch:      noarch

%description
LaTeX2HTML lets you convert basic LaTeX documents into the HTML
format. This allows both a written and online version even of older
LaTeX texts.

%package pngicons
Summary:        Icons in the PNG format for LateX2HTML
License:        GPL-2.0-or-later
Group:          Productivity/Publishing/TeX/Utilities

%description pngicons
Icons in the PNG format for the LaTeX to HTML Converter.

%package doc
Summary:        Documentation for the Latex2HTML Converter
License:        GPL-2.0-or-later AND LPPL-1.3c
Group:          Productivity/Publishing/TeX/Utilities

%description doc
This subpackage contains the documentation for the Latex2HTML converter.

%prep
%autosetup -p0

%build
# Not autotools based configure
./configure --prefix=%{_prefix}
%make_build
# Build docs
export LATEX2HTMLDIR=$(pwd)
cd docs
make L2H="../latex2html -nouse_pdftex -test_mode" html
find manual \( -name "*.old" -o -name "*.log" -o -name "*.aux" -o -name WARNINGS \) -delete

%install
%make_install
mkdir -p %{buildroot}/%{_mandir}/man1
install -m 644 latex2html.1 %{buildroot}/%{_mandir}/man1
rm -r %{buildroot}%{share_dir}/{docs,example,dot.latex2html-init}
chmod 755 %{buildroot}%{_datadir}/%{name}/{cweb2html/makemake.pl,cweb2html/cweb2html,makemap,makeseg/makeseg}
%fdupes -s %{buildroot}
touch tests # for identical mtime with/without --nocheck

%check
%make_build test
# cleanup after test to not modify the install result (boo#1227364)
find docs/manual tests \( -name \*.log -o -name \*.aux -o -name WARNINGS \) -delete
rm -rf tests/l2htest

%files
%doc Changes FAQ README.md TODO dot.latex2html-init
%{_prefix}/lib/latex2html
%dir %{share_dir}
%{share_dir}/*.pm
%{share_dir}/IndicTeX-HTML
%{share_dir}/L2hos
%{share_dir}/XyMTeX-HTML
%{share_dir}/cweb2html
%{share_dir}/foilhtml
%{share_dir}/icons/*.html
%{share_dir}/icons/*.gif
%{share_dir}/makemap
%{share_dir}/makeseg
%{share_dir}/styles
%{share_dir}/texinputs
%{share_dir}/versions
%{_bindir}/*
%{_texmfmaindir}/tex/latex/html
%{_mandir}/man1/latex2html*

%files pngicons
%dir %{share_dir}
%dir %{share_dir}/icons
%{share_dir}/icons/*.png

%files doc
%doc docs/manual
%doc tests
%doc example

%changelog
* Fri Jun 20 2025 Bernhard Wiedemann <bwiedemann@suse.com>
- Get fully determistic builds, even with --nocheck (boo#1227364)
* Thu Jan 16 2025 ming li <mli@suse.com>
- Update to version 2025
  * generate a numeric char reference for chars not found in the
    output character encoding.
  * fix \'{\i}
  * switch --entities no longer makes accents like &iacute;
  * fix \verb&A&
  * avoid processing eqnarray* as one image, make layout consistent
    with eqnarray
* Thu Oct 24 2024 ming li <mli@suse.com>
- Update to version 2024.2
  * fix pstoimg operator precedence bug
  * allow "-dir ." and "-rootdir ."
  * remove extra "showpage" from pstoimg
  * remove svg from config for pstoimg
  * new option -use_hilite
  * support minted package
  * new option -unicase_titles
* Fri Jul 19 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- cleanup after test to not modify the install result (boo#1227364)
* Thu Feb 29 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Mon Feb 26 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- Remove .log files during build
* Wed Feb 14 2024 pgajdos@suse.com
- version update to 2024
  * "make clean" removes manual.pdf
    https://bugs.debian.org/1046413
- modified patches
  %% latex2html-share-dir.diff (refreshed)
* Fri Jul 21 2023 pgajdos@suse.com
- version update to 2023.2
  * DONT_INCLUDE now affects \usepackage but not \input
  * support \usepackage[xindy]{imakeidx} for sorting accents
  * support babel main language option
  * support hyphenat package
* Fri Jan 20 2023 Dirk Müller <dmueller@suse.com>
- update to 2023:
  * update for latest pdftocairo
* Fri Jul 15 2022 Dirk Müller <dmueller@suse.com>
- update to 2022.2:
  * spacing of eqnarray and align
  * check for preview.sty in config.pl
  * check for failure of pdflatex run
  * newline after footnote should give space
  * fix ref to label inside float
  * add sidewaysfigure, sidewaystable
  * fix eqnarray*
- drop latex2html-binmode.diff.
  latex2html-dest-dir.diff, latex2html-perl-bindir.diff
* Thu Apr 21 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 2022
  * fix cropped figures
  * revert PreviewBorder to 0.5bp
  * support download attribute for <A> tag
  * remove meta tags for distribution, etc
  * allow input filename with no extension
- Remove outdated manual latex2html-manual.tar.bz2,
  build up-to-date manual from source as part of the build process.
- Drop latex2html-backref-workaround.diff, was a workaround for
  perl 5.18 not used in any supported openSUSE version anymore.
* Tue Aug 10 2021 pgajdos@suse.com
- do not package test logs (WARNINGS in this case) [bsc#1188918]
* Sun Jul  4 2021 Dirk Müller <dmueller@suse.com>
- update to 2021.2:
  * latex2html -long_titles   fix duplicate file names
  * latex2html -long_titles 5 -title "Title"
  * correct link from index.html
  * pnmquant -norandom    for reproducible builds
  * treat cygwin as unix
  * $WORDS_IN_INDEX configurable
  * fix image size for multline, subequations
  * remove extra <SPAN> after subequations
  * equation numbering for multline
  * close bold, etc, at end of environment
  * implement memoir document class
  * fix scanning of latex comments
  * fix subequation numbering
  * babel should not set character encoding of input file
  * package nomencl.sty
  * package nameref.sty
  * options -cut_ref_num -add_ref_name
* Sat Mar 13 2021 Dirk Müller <dmueller@suse.com>
- update to 2021:
  * implement listings package
  * support for \hyperref (hyperref.sty and html.sty syntax)
  * \multirow with automatic width (*)
  * support for length units em and ex in &convert_length
  * support for font-, page- and minipage-relative length units
  * support for specifying image size in wrapfigure
  * support for commands: \; \, \quad \qquad inside \textsc
  * \itemize[], \enumerate[], \description[] (discard argument)
  * &convert_to_unicode in style &#8221; for chars > 255
  * correct several special symbols for koi8-r encoding
  * repair \htmladdimg and user scaling in \includegraphics
  * repair scaling for undefined environments in use_dvipng mode
  * correct placement of the $\degree$ symbol in use_dvipng mode
  * repair scaling in nouse_dvipng mode
  * 256-color gif dithering via png16m followed by ppmquant
  * correct transparent color specification (for the $\_$ symbol)
  * correct Makefile for building manual
  * adjust spacing for eqnarray
  * fix alignment of eq numbers for safari
  * fix infinite loop on empty itemize env
  * make link to correct bibliography if there is more than one
  * "References" by default, "Bibliography" for book
* Tue Dec 22 2020 Dirk Müller <dmueller@suse.com>
- update to 2020.2:
  - gs 9.50: -dNOSAFER to write to tmp dir
  - css fix: put caption below figure
  - fix bug with gif with >256 colors
  - fix eqnarray*
  - fix "make test"
  - fix false matches when reusing images for long environments.
  - fork on \include, not on \input
  - fix figure size with png
  - allow verbatim in figure
  - output height with displaymath, center displaymath
  - enable -nouse_pdftex -image_type svg
  - fall back to unicode combining characters for accents
  - generate higher numbered UTF8 chars
* Thu Dec 19 2019 pgajdos@suse.com
- fix url
* Mon Sep 30 2019 pgajdos@suse.com
- texlive-preview was mistakenly added as build dependency, it
  should have been runtime dependency [bsc#1150208]
* Wed Sep 25 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Drop log files to make package build reproducible (boo#1047218)
* Wed Sep 11 2019 pgajdos@suse.com
- version update to 2019.2
  * format author block consistently
    https://bugs.debian.org/223565
  * simplify build of manual
    https://bugs.debian.org/639708
  * convert -- to &ndash; and --- to &mdash;
    If you want "--", use "-{}-", even inside \texttt{}
    Behavior of \textt{--} in latex depends on font encoding.
    https://bugs.debian.org/75416
  * fix unicode in -html_version 5.0,math
  * fix -notop_navigation (had no effect)
  * remove obsolete "table" option
    https://bugs.debian.org/276037
  * fix "make test"
  * ppmtopng syntax works with all versions of ppmtopng
  * respect ./configure --with-perl=/bin/perl
  * fallback for unknown column types, such as those
    introduced by \newcolumntype.
    https://bugs.debian.org/899306
  * fix \sffamily
    https://bugs.debian.org/111441
  * produce svg images using pdftocairo
  * use latex preview package to produce cropped images.pdf
  * pdflatex by default
  * dvipng by default
  * html 5
  * unicode input and output by default
  * Support for packages luainputenc and polyglossia
  * Support for picture generation via pdflatex, lualatex
    or dvilualatex (options -use_pdftex, -use_luatex,
  * use_luadvi correspondingly)
  * perl 5.26: unescaped brace
  * polski.perl: no translation until \prefixing command
- use native `make test`
- use latex2html.1 from tarball
- deleted patches
  - latex2html-perl526.patch (upstreamed)
- deleted sources
  - latex2html-README.SUSE (not needed)
  - local.pm (not needed)
  - testfile.tex (not needed)
- added required texlive-preview
* Mon Dec 31 2018 Petr Gajdos <pgajdos@suse.com>
- updated to 2018
  * config: avoid warning "untie attempted"
  * Handle . not in @INC for images.pl and internals.pl
  * fix \graphicspath with relative path in preamble
    https://github.com/latex2html/latex2html/issues/40
  * \providecommand should not redefine existing command
  * Picture generation via dvipng
  * KOI8-R, CP1251 and UTF-8 support for Russian
  * default to white background for rendering images.
    if $LATEX_COLOR set, pass as transparency color to pstoimg.
    https://bugs.debian.org/188024
  * usepackage xcolor.  uses rgb black rather than cmyk black.
    fixes eqns appearing as dark grey rather than black.
  * Fix stray comment mark: Issue #19
- altered patches
  %% latex2html-perl-bindir.diff
  %% latex2html-perl526.patch
* Sun Sep 24 2017 coolo@suse.com
- add latex2html-perl526.patch to work with perl 5.26
* Mon Jul 10 2017 jengelh@inai.de
- Fix descriptions.
* Wed Jul  5 2017 tchvatal@suse.com
- Version update to latest release 2017.2:
  * Various small fixes
- Sort out with spec-cleaner
- Remove post/postun phases expecting suseconfig to be around
* Mon Nov 21 2016 pgajdos@suse.com
- updated to 2016:
  * longtable: fix duplicate caption
  * pstoimg: fix pstoimg -depth 24 -flip cw
* Wed Dec 16 2015 pgajdos@suse.com
- updated to 2015: apply patches from Debian
  D    latex2html-2012-backref-workaround.diff
  D    latex2html-2012-binmode.diff
  D    latex2html-2012-dest-dir.diff
  D    latex2html-2012-gsout.diff (upstreamed)
  D    latex2html-2012-match-multiline.diff (upstreamed)
  D    latex2html-2012-perl-bindir.diff
  D    latex2html-2012-share-dir.diff
  A    latex2html-backref-workaround.diff
  A    latex2html-binmode.diff
  A    latex2html-dest-dir.diff
  A    latex2html-perl-bindir.diff
  A    latex2html-share-dir.diff
* Mon Oct  6 2014 crrodriguez@opensuse.org
- Remove BuildRequires on xorg-x11-*, noarch package
  does not require devel headers/libraries.
* Mon Mar 31 2014 pgajdos@suse.com
- fixed url
* Mon Nov 25 2013 pgajdos@suse.com
- updated to version 2012:
  * fix warnings in perl 5.14
  * build fixes
- latex2html-2008.diff was split to share-dir.patch, local.pm
  (source) and latex2html.1 (source)
- buildroot.diff was renamed to dest-dir.diff and that was extended
  to install icons properly
- fix-defined.patch was removed (upstreamed)
- manual.ps.gz was removed
* Tue Sep 10 2013 werner@suse.de
- Use kpsepath to determine texmf main location
* Tue Jun 25 2013 mls@suse.de
- use \g syntax for \8 and \9 regexp backrefs to work around
  a bug in perl-5.18
* Tue Jun 25 2013 coolo@suse.com
- add latex2html-fix-defined.patch from debian bug tracker to avoid
  a warning
- add apparmor's tex docu for better %%check: testfile.tex
* Thu Apr 11 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Mon Feb  4 2013 coolo@suse.com
- update license to new format
* Wed Mar 23 2011 vcizek@novell.com
- stopped using deprecated multiline matching (bnc#417982)
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Tue Jan 27 2009 pgajdos@suse.cz
- splitted off doc package
- fixed /usr/local/bin/perl -> /usr/bin/perl in scripts
  * perl-bindir.diff
* Tue Jan 20 2009 pgajdos@suse.cz
- updated to version 2008
  * bug fixes
* Fri Nov 28 2008 ro@suse.de
- drop some old requires and buildrequires
* Tue Mar 18 2008 pgajdos@suse.cz
- fixed build, *.sty files have moved to /usr/lib
* Fri Jun 15 2007 pgajdos@suse.cz
- removed out-dated url.sty [#283760]
- using fdupes
* Fri Apr 20 2007 aj@suse.de
- Use texlive.
* Mon Feb 12 2007 ro@suse.de
- fix build as non-root
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Feb 19 2005 ro@suse.de
- fix gs version detection
* Tue Jun  8 2004 ke@suse.de
- Add README.SuSE and document 'url' package incompatibility [#26127].
* Thu Mar  4 2004 tcrhak@suse.cz
- install into /usr/share/latex2html instead of /usr/share/lib/latex2html
  (bug #33641)
* Wed Oct 29 2003 tcrhak@suse.cz
- use latex2html instead of l2h in the man page [bug #32559]
- updated the man page
* Thu Aug 14 2003 kukuk@suse.de
- Fix filelist for pngicons subpackage
* Thu Jun 12 2003 kukuk@suse.de
- Fix filelist
* Fri Mar  7 2003 tcrhak@suse.cz
- open files in raw binmode - needed when in a UTF-8 locale
  [bug #22982]
* Wed Jan 15 2003 tcrhak@suse.cz
- update to version 2002.2.1
- directory ...latex2html/icons now owned by
  latex2html-pngicons, not latex2html
- removed split-alias from latex2html-pngicons,
  as it is required by latex2html
* Thu Oct 31 2002 ro@suse.de
- fixed renaming issues with pngicons subpackage
* Wed Oct 30 2002 mmj@suse.de
- When l2hhtml is merged into here, this one should obsolete it
* Wed Oct 30 2002 mmj@suse.de
- Rename to latex2html, and merge the l2hhtml package
* Thu Sep 12 2002 mls@suse.de
- made it understand DeclareRobustCommand
* Sun Aug 18 2002 ro@suse.de
- added ghostscript-x11-packages to neededforbuild (for gs)
* Mon Mar 25 2002 ro@suse.de
- l2h should require it's icons not vice versa
* Sat Mar 23 2002 ro@suse.de
- split off package l2h-pngicons
* Mon Feb 18 2002 tcrhak@suse.cz
- added libgimpprint to neededforbuild
* Fri Feb  1 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Thu Aug  2 2001 utuerk@suse.de
- added glib to Requires and neededforbuild
  to configure l2h to use png by default
* Thu Jul 26 2001 kukuk@suse.de
- fix needed for build
* Wed Jul 18 2001 nadvornik@suse.cz
- updated URL and README (bug #9386)
* Wed Mar  7 2001 cihlar@suse.cz
- fixed neededforbuild
* Thu Dec  7 2000 nadvornik@suse.cz
- added te_latex to Requires
* Fri Dec  1 2000 nadvornik@suse.cz
- update to 99.2beta8
* Wed Aug 30 2000 nadvornik@suse.cz
- configured to use png by default
* Thu Aug  3 2000 nadvornik@suse.cz
- added man page
- spec file cleanup
* Mon Sep 20 1999 ro@suse.de
- added Requires: ghostscript_any
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Aug  2 1999 ke@suse.de
- update: version 99.1
- the rc.config variables are gone.
* Wed Apr  7 1999 ro@suse.de
- fixed tex/latex link
* Thu Jul  2 1998 ro@suse.de
- fixed bash2-bug in SuSEconfig.l2h
* Wed Mar 18 1998 ro@suse.de
- added touch var/adm/SuSEconfig/run-texhash to %%post
* Tue Jun 10 1997 maddin@suse.de
- reordered the directory structure
  - latex2html now sits partly in /var/lib/latex2html (writable part) and
    /usr/lib/latex2html (read-only part)
- made absolute links relative ones
- removed some links
- restructured /sbin/conf.d/SuSEconfig.l2h
* Thu May 22 1997 maddin@suse.de
- first S.u.S.E. version 96-1.h
- placed the package in /usr/lib/latex2html
- documentation manual to separate package l2hhtml
- variables in rc.config to configure the package
